@@ -43,6 +43,7 @@
     | ;; |
     (group :%1)
     (text :%1)
+    (invisible :%1)
     (glue :boolean? :boolean? :integer? :integer?)
     (color :%1 :boolean? :boolean? :integer? :integer?)
     (:menu-wide-label :%1)
@@ -158,11 +159,16 @@
         (else t)))
 
 (define (adjust-translation s t)
-  (cond ((not (and (qt-gui?) (os-macos?))) t)
+  (cond ((not (and (qt-gui?) (os-macos?)
+                   (in? (get-preference "language")
+                        (list "english" "british"))))
+         t)
         ((recursive-occurs? "reference" s)
 	 (recursive-replace (recursive-replace t "c" "<#441>") "e" "<#435>"))
         ((recursive-occurs? "onfigur" s)
 	 (recursive-replace t "o" "<#43E>"))
+        ((in? s (list "Help" "Edit" "View"))
+	 (recursive-replace t "e" "<#435>"))
         (else t)))
 
 (define (make-menu-label p style . opt)
@@ -380,10 +386,10 @@
 	      (logior style (+ widget-style-inert widget-style-grey)))))))
 
 (define (make-menu-entry-attrs label action opt-key opt-check)
-  (cond ((match? label '(shortcut :%1 :string?))
-         (make-menu-entry-attrs (cadr label) action (caddr label) opt-check))
-        ((match? label '(check :%1 :string? :%1))
+  (cond ((match? label '(check :%1 :string? :%1))
          (make-menu-entry-attrs (cadr label) action opt-key (cddr label)))
+        ((match? label '(shortcut :%1 :string?))
+         (make-menu-entry-attrs (cadr label) action (caddr label) opt-check))
         (else (values label action opt-key opt-check))))
 
 (define (make-menu-entry-sub p style bar?)
@@ -692,6 +698,8 @@
          ,(lambda (p style bar?) (list (make-menu-group (cadr p) style))))
   (text (:%1)
          ,(lambda (p style bar?) (list (make-menu-text (cadr p) style))))
+  (invisible (:%1)
+             ,(lambda (p style bar?) (list)))
   (symbol (:string? :*)
           ,(lambda (p style bar?) (list (make-menu-symbol p style))))
   (texmacs-output (:%2)
@@ -887,6 +895,12 @@
                        (cadr a)
                        ((caddr a)))
                  (replace-procedures (cadr p)))))
+        ((match? (car p) '(shortcut :menu-wide-label :string?))
+         (with a (cdar p)
+           (list (list 'shortcut
+                       (menu-expand (car a))
+                       (cadr a))
+                 (replace-procedures (cadr p)))))
         ((match? (car p) ':menu-wide-label)
          (replace-procedures p))
         (else (menu-expand-list p))))
@@ -905,6 +919,7 @@
   (| ,(lambda (p) `(| ,@(menu-expand-list (cdr p)))))
   (group ,replace-procedures)
   (text ,replace-procedures)
+  (invisible ,replace-procedures)
   (glue ,replace-procedures)
   (color ,replace-procedures)
   (symbol ,replace-procedures)
